@@ -47,7 +47,9 @@
 #'
 #' @return A dataset containing the first or last observation of each by group
 #'
-#' @keywords adam user_utility
+#' @family utils_fil
+#'
+#' @keywords utils_fil
 #'
 #' @export
 #'
@@ -89,12 +91,13 @@ filter_extreme <- function(dataset,
     )
 
   # group and sort input dataset
+  tmp_obs_nr <- get_new_tmp_var(dataset)
   if (!is.null(by_vars)) {
     assert_has_variables(dataset, vars2chr(by_vars))
 
     data <- dataset %>%
       derive_var_obs_number(
-        new_var = temp_obs_nr,
+        new_var = !!tmp_obs_nr,
         order = order,
         by_vars = by_vars,
         check_type = check_type
@@ -103,7 +106,7 @@ filter_extreme <- function(dataset,
   } else {
     data <- dataset %>%
       derive_var_obs_number(
-        new_var = temp_obs_nr,
+        new_var = !!tmp_obs_nr,
         order = order,
         check_type = check_type
       )
@@ -120,5 +123,5 @@ filter_extreme <- function(dataset,
   }
   data %>%
     ungroup() %>%
-    select(-starts_with("temp_"))
+    remove_tmp_vars()
 }
